@@ -13,7 +13,6 @@ from ..utils import base64url_decode
 
 
 class ECKey(KEMKeyInterface):
-
     """
     The EC key for KEM.
     """
@@ -68,7 +67,7 @@ class ECKey(KEMKeyInterface):
             else:
                 raise ValueError("Coords should be 66 bytes for curve P-521")
         else:
-            raise ValueError(f"Invalid curve: {crv}")
+            raise ValueError(f"Invalid curve: {jwk['crv']}.")
 
         public_numbers = ec.EllipticCurvePublicNumbers(
             x=int.from_bytes(x, byteorder="big"),
@@ -85,6 +84,12 @@ class ECKey(KEMKeyInterface):
 
         return cls(ec.EllipticCurvePrivateNumbers(int.from_bytes(d, byteorder="big"), public_numbers).private_key())
 
+    def to_private_bytes(self) -> bytes:
+        if self._is_public:
+            raise ValueError("The key is public")
+        private_value = self._key.private_numbers().private_value  # type: int
+        return private_value.to_bytes(self._key.key_size, "big")
+
     def to_public_bytes(self) -> bytes:
         """
         Serializes the key to a byte string.
