@@ -8,7 +8,6 @@ from ..utils import base64url_decode
 
 
 class X448Key(KEMKeyInterface):
-
     """
     The X448 key for KEM.
     """
@@ -55,6 +54,11 @@ class X448Key(KEMKeyInterface):
             raise ValueError(f"D should be {len(x)} bytes for {jwk['crv']}")
         return cls(X448PrivateKey.from_private_bytes(d))
 
+    def to_private_bytes(self) -> bytes:
+        if self._is_public:
+            raise ValueError("The key is public")
+        return self._key.private_bytes_raw()
+
     def to_public_bytes(self) -> bytes:
         """
         Serializes the key to a byte string.
